Class: Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb

Overview

Client for the CloudControlsPartnerCore service.

Service describing handlers for resources

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#customer_path, #ekm_connections_path, #organization_location_path, #partner_path, #partner_permissions_path, #workload_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new CloudControlsPartnerCore client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the CloudControlsPartnerCore client.

Yield Parameters:



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 159

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/cloudcontrolspartner/v1beta/core_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @cloud_controls_partner_core_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @cloud_controls_partner_core_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the CloudControlsPartnerCore Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all CloudControlsPartnerCore clients
::Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "CloudControlsPartner", "V1beta"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.get_workload.timeout = 60.0
    default_config.rpcs.get_workload.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_workloads.timeout = 60.0
    default_config.rpcs.list_workloads.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_customer.timeout = 60.0
    default_config.rpcs.get_customer.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_customers.timeout = 60.0
    default_config.rpcs.list_customers.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_ekm_connections.timeout = 60.0
    default_config.rpcs.get_ekm_connections.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.get_partner_permissions.timeout = 60.0
    default_config.rpcs.get_partner_permissions.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.list_access_approval_requests.timeout = 60.0
    default_config.rpcs.list_access_approval_requests.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the CloudControlsPartnerCore Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



129
130
131
132
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 129

def configure
  yield @config if block_given?
  @config
end

#create_customer(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer #create_customer(parent: nil, customer: nil, customer_id: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer

Creates a new customer.

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::CreateCustomerRequest.new

# Call the create_customer method.
result = client.create_customer request

# The returned object is of type Google::Cloud::CloudControlsPartner::V1beta::Customer.
p result

Overloads:

  • #create_customer(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer

    Pass arguments to create_customer via a request object, either of type Google::Cloud::CloudControlsPartner::V1beta::CreateCustomerRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::CreateCustomerRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_customer(parent: nil, customer: nil, customer_id: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer

    Pass arguments to create_customer via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent resource Format: organizations/{organization}/locations/{location}

    • customer (::Google::Cloud::CloudControlsPartner::V1beta::Customer, ::Hash) (defaults to: nil)

      Required. The customer to create.

    • customer_id (::String) (defaults to: nil)

      Required. The customer id to use for the customer, which will become the final component of the customer's resource name. The specified value must be a valid Google cloud organization id.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 1015

def create_customer request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::CreateCustomerRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_customer..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_customer.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_customer.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :create_customer, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_customer(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_customer(name: nil) ⇒ ::Google::Protobuf::Empty

Delete details of a single customer

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::DeleteCustomerRequest.new

# Call the delete_customer method.
result = client.delete_customer request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_customer(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_customer via a request object, either of type DeleteCustomerRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::DeleteCustomerRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_customer(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_customer via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. name of the resource to be deleted format: name=organizations//locations//customers/*

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 1190

def delete_customer request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::DeleteCustomerRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_customer..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_customer.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_customer.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :delete_customer, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_customer(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer #get_customer(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer

Gets details of a single customer

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::GetCustomerRequest.new

# Call the get_customer method.
result = client.get_customer request

# The returned object is of type Google::Cloud::CloudControlsPartner::V1beta::Customer.
p result

Overloads:

  • #get_customer(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer

    Pass arguments to get_customer via a request object, either of type GetCustomerRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::GetCustomerRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_customer(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer

    Pass arguments to get_customer via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Format: organizations/{organization}/locations/{location}/customers/{customer}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 455

def get_customer request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::GetCustomerRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_customer..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_customer.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_customer.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :get_customer, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_ekm_connections(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::EkmConnections #get_ekm_connections(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::EkmConnections

Gets the EKM connections associated with a workload

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::GetEkmConnectionsRequest.new

# Call the get_ekm_connections method.
result = client.get_ekm_connections request

# The returned object is of type Google::Cloud::CloudControlsPartner::V1beta::EkmConnections.
p result

Overloads:

  • #get_ekm_connections(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::EkmConnections

    Pass arguments to get_ekm_connections via a request object, either of type GetEkmConnectionsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::GetEkmConnectionsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_ekm_connections(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::EkmConnections

    Pass arguments to get_ekm_connections via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Format: organizations/{organization}/locations/{location}/customers/{customer}/workloads/{workload}/ekmConnections

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 643

def get_ekm_connections request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::GetEkmConnectionsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_ekm_connections..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_ekm_connections.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_ekm_connections.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :get_ekm_connections, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_partner(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Partner #get_partner(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Partner

Get details of a Partner.

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::GetPartnerRequest.new

# Call the get_partner method.
result = client.get_partner request

# The returned object is of type Google::Cloud::CloudControlsPartner::V1beta::Partner.
p result

Overloads:

  • #get_partner(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Partner

    Pass arguments to get_partner via a request object, either of type GetPartnerRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::GetPartnerRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_partner(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Partner

    Pass arguments to get_partner via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Format: organizations/{organization}/locations/{location}/partner

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 923

def get_partner request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::GetPartnerRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_partner..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_partner.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_partner.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :get_partner, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_partner_permissions(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::PartnerPermissions #get_partner_permissions(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::PartnerPermissions

Gets the partner permissions granted for a workload

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::GetPartnerPermissionsRequest.new

# Call the get_partner_permissions method.
result = client.get_partner_permissions request

# The returned object is of type Google::Cloud::CloudControlsPartner::V1beta::PartnerPermissions.
p result

Overloads:

  • #get_partner_permissions(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::PartnerPermissions

    Pass arguments to get_partner_permissions via a request object, either of type GetPartnerPermissionsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::GetPartnerPermissionsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_partner_permissions(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::PartnerPermissions

    Pass arguments to get_partner_permissions via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Name of the resource to get in the format: organizations/{organization}/locations/{location}/customers/{customer}/workloads/{workload}/partnerPermissions

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 729

def get_partner_permissions request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::GetPartnerPermissionsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_partner_permissions..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_partner_permissions.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_partner_permissions.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :get_partner_permissions, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_workload(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Workload #get_workload(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Workload

Gets details of a single workload

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::GetWorkloadRequest.new

# Call the get_workload method.
result = client.get_workload request

# The returned object is of type Google::Cloud::CloudControlsPartner::V1beta::Workload.
p result

Overloads:

  • #get_workload(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Workload

    Pass arguments to get_workload via a request object, either of type GetWorkloadRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::GetWorkloadRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_workload(name: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Workload

    Pass arguments to get_workload via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. Format: organizations/{organization}/locations/{location}/customers/{customer}/workloads/{workload}

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 266

def get_workload request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::GetWorkloadRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_workload..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_workload.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_workload.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :get_workload, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_access_approval_requests(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::AccessApprovalRequest> #list_access_approval_requests(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::AccessApprovalRequest>

Deprecated.

This method is deprecated and may be removed in the next major version update.

Deprecated: Only returns access approval requests directly associated with an assured workload folder.

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::ListAccessApprovalRequestsRequest.new

# Call the list_access_approval_requests method.
result = client.list_access_approval_requests request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudControlsPartner::V1beta::AccessApprovalRequest.
  p item
end

Overloads:

  • #list_access_approval_requests(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::AccessApprovalRequest>

    Pass arguments to list_access_approval_requests via a request object, either of type ListAccessApprovalRequestsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::ListAccessApprovalRequestsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_access_approval_requests(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::AccessApprovalRequest>

    Pass arguments to list_access_approval_requests via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent resource Format: organizations/{organization}/locations/{location}/customers/{customer}/workloads/{workload}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of access requests to return. The service may return fewer than this value. If unspecified, at most 500 access requests will be returned.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListAccessApprovalRequests call. Provide this to retrieve the subsequent page.

    • filter (::String) (defaults to: nil)

      Optional. Filtering results.

    • order_by (::String) (defaults to: nil)

      Optional. Hint for how to order the results.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 835

def list_access_approval_requests request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::ListAccessApprovalRequestsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_access_approval_requests..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_access_approval_requests.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_access_approval_requests.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :list_access_approval_requests, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @cloud_controls_partner_core_stub, :list_access_approval_requests, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_customers(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Customer> #list_customers(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Customer>

Lists customers of a partner identified by its Google Cloud organization ID

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::ListCustomersRequest.new

# Call the list_customers method.
result = client.list_customers request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudControlsPartner::V1beta::Customer.
  p item
end

Overloads:

  • #list_customers(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Customer>

    Pass arguments to list_customers via a request object, either of type ListCustomersRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::ListCustomersRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_customers(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Customer>

    Pass arguments to list_customers via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent resource Format: organizations/{organization}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of Customers to return. The service may return fewer than this value. If unspecified, at most 500 Customers will be returned.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListCustomers call. Provide this to retrieve the subsequent page.

    • filter (::String) (defaults to: nil)

      Optional. Filtering results

    • order_by (::String) (defaults to: nil)

      Optional. Hint for how to order the results

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 555

def list_customers request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::ListCustomersRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_customers..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_customers.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_customers.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :list_customers, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @cloud_controls_partner_core_stub, :list_customers, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_workloads(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Workload> #list_workloads(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Workload>

Lists customer workloads for a given customer org id

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::ListWorkloadsRequest.new

# Call the list_workloads method.
result = client.list_workloads request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::CloudControlsPartner::V1beta::Workload.
  p item
end

Overloads:

  • #list_workloads(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Workload>

    Pass arguments to list_workloads via a request object, either of type ListWorkloadsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::CloudControlsPartner::V1beta::ListWorkloadsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_workloads(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::CloudControlsPartner::V1beta::Workload>

    Pass arguments to list_workloads via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. Parent resource Format: organizations/{organization}/locations/{location}/customers/{customer}

    • page_size (::Integer) (defaults to: nil)

      The maximum number of workloads to return. The service may return fewer than this value. If unspecified, at most 500 workloads will be returned.

    • page_token (::String) (defaults to: nil)

      A page token, received from a previous ListWorkloads call. Provide this to retrieve the subsequent page.

    • filter (::String) (defaults to: nil)

      Optional. Filtering results.

    • order_by (::String) (defaults to: nil)

      Optional. Hint for how to order the results.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 367

def list_workloads request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::ListWorkloadsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_workloads..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_workloads.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_workloads.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :list_workloads, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @cloud_controls_partner_core_stub, :list_workloads, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


215
216
217
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 215

def logger
  @cloud_controls_partner_core_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


139
140
141
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 139

def universe_domain
  @cloud_controls_partner_core_stub.universe_domain
end

#update_customer(request, options = nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer #update_customer(customer: nil, update_mask: nil) ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Customer

Update details of a single customer

Examples:

Basic example

require "google/cloud/cloud_controls_partner/v1beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::CloudControlsPartner::V1beta::CloudControlsPartnerCore::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::CloudControlsPartner::V1beta::UpdateCustomerRequest.new

# Call the update_customer method.
result = client.update_customer request

# The returned object is of type Google::Cloud::CloudControlsPartner::V1beta::Customer.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
# File 'lib/google/cloud/cloud_controls_partner/v1beta/cloud_controls_partner_core/client.rb', line 1104

def update_customer request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::CloudControlsPartner::V1beta::UpdateCustomerRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_customer..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::CloudControlsPartner::V1beta::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.customer&.name
    header_params["customer.name"] = request.customer.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_customer.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_customer.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @cloud_controls_partner_core_stub.call_rpc :update_customer, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end