Class: Google::Cloud::CloudControlsPartner::V1beta::CreateCustomerRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudcontrolspartner/v1beta/customers.rb

Overview

Request to create a customer

Instance Attribute Summary collapse

Instance Attribute Details

#customer::Google::Cloud::CloudControlsPartner::V1beta::Customer

Returns Required. The customer to create.

Returns:



100
101
102
103
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customers.rb', line 100

class CreateCustomerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#customer_id::String

Returns Required. The customer id to use for the customer, which will become the final component of the customer's resource name. The specified value must be a valid Google cloud organization id.

Returns:

  • (::String)

    Required. The customer id to use for the customer, which will become the final component of the customer's resource name. The specified value must be a valid Google cloud organization id.



100
101
102
103
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customers.rb', line 100

class CreateCustomerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent resource Format: organizations/{organization}/locations/{location}.

Returns:

  • (::String)

    Required. Parent resource Format: organizations/{organization}/locations/{location}



100
101
102
103
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customers.rb', line 100

class CreateCustomerRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end