Class: Google::Cloud::CloudControlsPartner::V1beta::EkmConnection

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudcontrolspartner/v1beta/ekm_connections.rb

Overview

Details about the EKM connection

Defined Under Namespace

Modules: ConnectionState Classes: ConnectionError

Instance Attribute Summary collapse

Instance Attribute Details

#connection_error::Google::Cloud::CloudControlsPartner::V1beta::EkmConnection::ConnectionError

Returns The connection error that occurred if any.

Returns:



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/ekm_connections.rb', line 58

class EkmConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Information around the error that occurred if the connection state is
  # anything other than available or unspecified
  # @!attribute [rw] error_domain
  #   @return [::String]
  #     The error domain for the error
  # @!attribute [rw] error_message
  #   @return [::String]
  #     The error message for the error
  class ConnectionError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The EKM connection state.
  module ConnectionState
    # Unspecified EKM connection state
    CONNECTION_STATE_UNSPECIFIED = 0

    # Available EKM connection state
    AVAILABLE = 1

    # Not available EKM connection state
    NOT_AVAILABLE = 2

    # Error EKM connection state
    ERROR = 3

    # Permission denied EKM connection state
    PERMISSION_DENIED = 4
  end
end

#connection_name::String

Returns Resource name of the EKM connection in the format: projects/{project}/locations/{location}/ekmConnections/{ekm_connection}.

Returns:

  • (::String)

    Resource name of the EKM connection in the format: projects/{project}/locations/{location}/ekmConnections/{ekm_connection}



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/ekm_connections.rb', line 58

class EkmConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Information around the error that occurred if the connection state is
  # anything other than available or unspecified
  # @!attribute [rw] error_domain
  #   @return [::String]
  #     The error domain for the error
  # @!attribute [rw] error_message
  #   @return [::String]
  #     The error message for the error
  class ConnectionError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The EKM connection state.
  module ConnectionState
    # Unspecified EKM connection state
    CONNECTION_STATE_UNSPECIFIED = 0

    # Available EKM connection state
    AVAILABLE = 1

    # Not available EKM connection state
    NOT_AVAILABLE = 2

    # Error EKM connection state
    ERROR = 3

    # Permission denied EKM connection state
    PERMISSION_DENIED = 4
  end
end

#connection_state::Google::Cloud::CloudControlsPartner::V1beta::EkmConnection::ConnectionState (readonly)

Returns Output only. The connection state.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/ekm_connections.rb', line 58

class EkmConnection
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Information around the error that occurred if the connection state is
  # anything other than available or unspecified
  # @!attribute [rw] error_domain
  #   @return [::String]
  #     The error domain for the error
  # @!attribute [rw] error_message
  #   @return [::String]
  #     The error message for the error
  class ConnectionError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The EKM connection state.
  module ConnectionState
    # Unspecified EKM connection state
    CONNECTION_STATE_UNSPECIFIED = 0

    # Available EKM connection state
    AVAILABLE = 1

    # Not available EKM connection state
    NOT_AVAILABLE = 2

    # Error EKM connection state
    ERROR = 3

    # Permission denied EKM connection state
    PERMISSION_DENIED = 4
  end
end