Class: Google::Cloud::CloudControlsPartner::V1beta::GetPartnerPermissionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/cloudcontrolspartner/v1beta/partner_permissions.rb

Overview

Request for getting the partner permissions granted for a workload

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. Name of the resource to get in the format: organizations/{organization}/locations/{location}/customers/{customer}/workloads/{workload}/partnerPermissions.

Returns:

  • (::String)

    Required. Name of the resource to get in the format: organizations/{organization}/locations/{location}/customers/{customer}/workloads/{workload}/partnerPermissions



62
63
64
65
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/partner_permissions.rb', line 62

class GetPartnerPermissionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end