Class: Google::Cloud::CloudControlsPartner::V1beta::Workload
- Inherits:
-
Object
- Object
- Google::Cloud::CloudControlsPartner::V1beta::Workload
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb
Overview
Contains metadata around the Workload resource in the Assured Workloads API.
Defined Under Namespace
Modules: Partner
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#folder ⇒ ::String
readonly
Output only.
-
#folder_id ⇒ ::Integer
readonly
Output only.
-
#is_onboarded ⇒ ::Boolean
Indicates whether a workload is fully onboarded.
-
#key_management_project_id ⇒ ::String
The project id of the key management project for the workload.
-
#location ⇒ ::String
The Google Cloud location of the workload.
-
#name ⇒ ::String
Identifier.
-
#partner ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Workload::Partner
Partner associated with this workload.
-
#workload_onboarding_state ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::WorkloadOnboardingState
Container for workload onboarding steps.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time the resource was created.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#folder ⇒ ::String (readonly)
Returns Output only. The name of container folder of the assured workload.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#folder_id ⇒ ::Integer (readonly)
Returns Output only. Folder id this workload is associated with.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#is_onboarded ⇒ ::Boolean
Returns Indicates whether a workload is fully onboarded.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#key_management_project_id ⇒ ::String
Returns The project id of the key management project for the workload.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#location ⇒ ::String
Returns The Google Cloud location of the workload.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#name ⇒ ::String
Returns Identifier. Format:
organizations/{organization}/locations/{location}/customers/{customer}/workloads/{workload}.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#partner ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::Workload::Partner
Returns Partner associated with this workload.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |
#workload_onboarding_state ⇒ ::Google::Cloud::CloudControlsPartner::V1beta::WorkloadOnboardingState
Returns Container for workload onboarding steps.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'proto_docs/google/cloud/cloudcontrolspartner/v1beta/customer_workloads.rb', line 55 class Workload include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Supported Assured Workloads Partners. module Partner # Unknown Partner. PARTNER_UNSPECIFIED = 0 # Enum representing S3NS (Thales) partner. PARTNER_LOCAL_CONTROLS_BY_S3NS = 1 # Enum representing T_SYSTEM (TSI) partner. PARTNER_SOVEREIGN_CONTROLS_BY_T_SYSTEMS = 2 # Enum representing SIA_MINSAIT (Indra) partner. PARTNER_SOVEREIGN_CONTROLS_BY_SIA_MINSAIT = 3 # Enum representing PSN (TIM) partner. PARTNER_SOVEREIGN_CONTROLS_BY_PSN = 4 # Enum representing CNTXT (Kingdom of Saudi Arabia) partner. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT = 6 # Enum representing CNXT (Kingdom of Saudi Arabia) partner offering without # EKM provisioning. PARTNER_SOVEREIGN_CONTROLS_BY_CNTXT_NO_EKM = 7 end end |